/*
' DotNetNuke - http:'www.dotnetnuke.com
' Copyright (c) 2002-2007
' by DotNetNuke Corporation
'
' Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
' documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
' the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
' to permit persons to whom the Software is furnished to do so, subject to the following conditions:
'
' The above copyright notice and this permission notice shall be included in all copies or substantial portions 
' of the Software.
'
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
' DEALINGS IN THE SOFTWARE.
 */

using System;
using System.Collections;

using DotNetNuke.Common.Utilities;
using DotNetNuke.Entities.Modules;
using DotNetNuke.Entities.Portals;
using System.ComponentModel;
using DotNetNuke.Services.Authentication;
using DotNetNuke.UI.WebControls;
using System.Collections.Generic;

namespace DotNetNuke.Authentication.LiveID
{
    /// <summary>
    /// The Config class provides a central area for management of Module Configuration Settings.
    /// </summary>
    public class Config : AuthenticationConfigBase
    {

        #region Private Members

        private string _AppID = Null.NullString;
        private bool _Enabled = Null.NullBoolean;
        private bool _IncludeHelp = Null.NullBoolean;
        private string _SecretKey = Null.NullString;

        private const string CACHEKEY = "Authentication.LiveID";

        #endregion

        #region Constructors

        /// <summary>
        /// Constructor for the Config class
        /// </summary>
        /// <remarks>The Constructort is private forcing the class to be constructed by calling the
        /// static GetConfig factory method</remarks>
        protected Config(int portalID)
            : base(portalID)
        {
            try
            {
                Dictionary<string, string> settings = PortalController.GetPortalSettingsDictionary(portalID);
                _Enabled = PortalController.GetPortalSettingAsBoolean("LiveID_Enabled", portalID, Null.NullBoolean);
                _AppID = PortalController.GetPortalSetting("LiveID_AppID", portalID, Null.NullString);
                _IncludeHelp = PortalController.GetPortalSettingAsBoolean("LiveID_IncludeHelp", portalID, Null.NullBoolean);
                _SecretKey = PortalController.GetPortalSetting("LiveID_SecretKey", portalID, Null.NullString);
            }
            catch
            {
            }
        }

        #endregion

        #region Public Properties

        public string AppID
        {
            get { return _AppID; }
            set { _AppID = value; }
        }

        public bool Enabled
        {
            get { return _Enabled; }
            set { _Enabled = value; }
        }

        public bool IncludeHelp
        {
            get { return _IncludeHelp; }
            set { _IncludeHelp = value; }
        }

        public string SecretKey
        {
            get { return _SecretKey; }
            set { _SecretKey = value; }
        }

        #endregion


        public static Config GetConfig(int portalId)
        {
            return new Config(portalId);
        }

        public static void UpdateConfig(Config config)
        {
            ModuleController controller = new ModuleController();

            PortalController.UpdatePortalSetting(config.PortalID, "LiveID_Enabled", config.Enabled.ToString());
            PortalController.UpdatePortalSetting(config.PortalID, "LiveID_AppID", config.AppID);
            PortalController.UpdatePortalSetting(config.PortalID, "LiveID_SecretKey", config.SecretKey);
            PortalController.UpdatePortalSetting(config.PortalID, "LiveID_IncludeHelp", config.IncludeHelp.ToString());
        }
        
        
    }
}
