/*
' DotNetNuke - http:'www.dotnetnuke.com
' Copyright (c) 2002-2007
' by DotNetNuke Corporation
'
' Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
' documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
' the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
' to permit persons to whom the Software is furnished to do so, subject to the following conditions:
'
' The above copyright notice and this permission notice shall be included in all copies or substantial portions 
' of the Software.
'
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
' DEALINGS IN THE SOFTWARE.
 */

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotNetNuke.Services.Authentication;
using DotNetNuke.Entities.Modules;
using DotNetNuke.UI.Utilities;
using DotNetNuke;
using DotNetNuke.Entities.Users;
using DotNetNuke.Security.Membership;
using DotNetNuke.Common;
using DotNetNuke.Common.Utilities;

namespace DotNetNuke.Authentication.LiveID
{
    public partial class Login : AuthenticationLoginBase
    {

        private string appID;
        const string LoginCookie = "webauthtoken";
        static DateTime ExpireCookie = DateTime.Now.AddYears(-10);
        static DateTime PersistCookie = DateTime.Now.AddYears(10);

        #region Public Properties

        /// <summary>
        /// AppID is the LiveID Apllication ID for this Portal
        /// </summary>
        public string AppID
        {
            get { return appID; }
            set { appID = value; }
        }

        /// <summary>
        /// Enabled is a flag that determines whether LiveID is enabled for this portal
        /// </summary>
        public override bool Enabled
        {
            get { return Config.GetConfig(PortalId).Enabled; }
        }

        /// <summary>
        /// ReturnURL is the URL to redirect to after successful login.  While this
        /// control does not do the redirect, as the control requires a "redirect" to
        /// an external LiveID page, this control manages this value and passes it to 
        /// the parent control on succesful Authentication
        /// </summary>
        public string ReturnURL
        {
            get
            {
                return Null.NullString;
            }
        }

        #endregion

        #region Private Methods

        private void loginUser(User user)
        {
            //Try and Log User into DNN
            UserLoginStatus loginStatus = UserLoginStatus.LOGIN_FAILURE;
            UserInfo objUser = UserController.ValidateUser(PortalId, user.Id, "", "LiveID", "", PortalSettings.PortalName, IPAddress, ref loginStatus);

            //Raise UserAuthenticated Event
            UserAuthenticatedEventArgs eventArgs = new UserAuthenticatedEventArgs(objUser, user.Id, loginStatus, "LiveID");

            OnUserAuthenticated(eventArgs);
        }
        #endregion

        #region Protected Methods

        protected override void OnInit(EventArgs e)
        {
            cmdLogin.Click += new EventHandler(cmdLogin_Click);
            base.OnInit(e);

            Config config = Config.GetConfig(PortalId);
            trHelp.Visible = config.IncludeHelp;
        }

        protected override void OnLoad(EventArgs e)
        {
            HttpResponse res = HttpContext.Current.Response;
            HttpRequest req = HttpContext.Current.Request;
            HttpCookie loginCookie = req.Cookies[LoginCookie];

            try
            {
                //Initialize WindowsLiveLogin class
                WindowsLiveLogin wll = new WindowsLiveLogin(PortalId);

                if (loginCookie != null)
                {
                    string token = loginCookie.Value;

                    if ((token != null) && (token.Length != 0))
                    {
                        User user = wll.ProcessToken(token);

                        if (user != null)
                        {
                            //Try and Log User into DNN
                            loginUser(user);
                        }
                    }
                }
                else
                {
                    //check what action it needs to perform by looking at the query string
                    string action = req.Params["action"];

                    /*
                      If action is 'logout', clear the login cookie and redirect
                      to the logout page.

                      If action is 'clearcookie', clear the login cookie and
                      return a GIF as response to signify success.

                      By default, try to process a login. If login was
                      successful, cache the user token in a cookie and redirect
                      to the site's main page.  If login failed, clear the cookie
                      and redirect to the main page.
                    */
                    loginCookie = new HttpCookie(LoginCookie);
                    switch (action)
                    {
                        case "logout":
                            loginCookie.Expires = ExpireCookie;
                            res.Cookies.Add(loginCookie);
                            res.Redirect(AuthenticationController.GetLogoffRedirectURL(PortalSettings, Request));
                            break;
                        case "clearcookie":
                            /* This action is called when the user tries to log-out.  */
                            // insert your clear cookie logic here */
                            // after cookies are cleared, you must reply to Windows Live ID server 
                            // Confirm successful sign out by sending an http response.
                            loginCookie.Expires = ExpireCookie;
                            res.Cookies.Add(loginCookie);

                            string type;
                            byte[] content;
                            wll.GetClearCookieResponse(out type, out content);
                            res.ContentType = type;
                            res.OutputStream.Write(content, 0, content.Length);
                            break;
                        case "login":
                            User user = wll.ProcessLogin(req.Form);
                            if (user != null)
                            {
                                loginCookie.Value = user.Token;

                                if (user.UsePersistentCookie)
                                {
                                    loginCookie.Expires = PersistCookie;
                                }

                                //Try and Log User into DNN
                                loginUser(user);
                            }
                            else
                            {
                                loginCookie.Expires = ExpireCookie;
                            }

                            res.Cookies.Add(loginCookie);
                            break;
                        default:
                            break;
                    }
                }

                tblLogin.Visible = true;
                pnlError.Visible = false;
            }
            catch (Exception exc)
            {
                tblLogin.Visible = false;
                pnlError.Visible = true;
            }
        }

        #endregion

        protected void cmdLogin_Click(object sender, EventArgs e)
        {
            //Initialize Windows Live Login
            WindowsLiveLogin wll = new WindowsLiveLogin(PortalId);

            Response.Redirect(wll.GetLoginUrl());
        }

    }
}